"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, resource_id: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Creates a tag for an EFS resource. You can create tags for EFS file systems and access points using this API operation. This operation requires permissions for the elasticfilesystem:TagResource action.

    Args:
        resource_id(str): The ID specifying the EFS resource that you want to create a tag for.
        tags(List): An array of Tag objects to add. Each Tag object is a key-value pair.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.resource.tag(ctx, resource_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.resource.tag resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="tag_resource",
        op_kwargs={"ResourceId": resource_id, "Tags": tags},
    )


async def untag(hub, ctx, resource_id: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags from an EFS resource. You can remove tags from EFS file systems and access points using this API operation. This operation requires permissions for the elasticfilesystem:UntagResource action.

    Args:
        resource_id(str): Specifies the EFS resource that you want to remove tags from.
        tag_keys(List): The keys of the key-value tag pairs that you want to remove from the specified EFS resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.resource.untag(ctx, resource_id=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.resource.untag resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="untag_resource",
        op_kwargs={"ResourceId": resource_id, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assume(
    hub,
    ctx,
    role_arn: str,
    principal_arn: str,
    saml_assertion: str,
    policy_arns: List = None,
    policy: str = None,
    duration_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a set of temporary security credentials for users who have been authenticated via a SAML authentication response. This operation provides a mechanism for tying an enterprise identity store or directory to role-based Amazon Web Services access without user-specific credentials or configuration. For a comparison of AssumeRoleWithSAML with the other API operations that produce temporary credentials, see Requesting Temporary Security Credentials and Comparing the STS API operations in the IAM User Guide. The temporary security credentials returned by this operation consist of an access key ID, a secret access key, and a security token. Applications can use these temporary security credentials to sign calls to Amazon Web Services services.  Session Duration  By default, the temporary security credentials created by AssumeRoleWithSAML last for one hour. However, you can use the optional DurationSeconds parameter to specify the duration of your session. Your role session lasts for the duration that you specify, or until the time specified in the SAML authentication response's SessionNotOnOrAfter value, whichever is shorter. You can provide a DurationSeconds value from 900 seconds (15 minutes) up to the maximum session duration setting for the role. This setting can have a value from 1 hour to 12 hours. To learn how to view the maximum value for your role, see View the Maximum Session Duration Setting for a Role in the IAM User Guide. The maximum session duration limit applies when you use the AssumeRole* API operations or the assume-role* CLI commands. However the limit does not apply when you use those operations to create a console URL. For more information, see Using IAM Roles in the IAM User Guide.   Role chaining limits your CLI or Amazon Web Services API role session to a maximum of one hour. When you use the AssumeRole API operation to assume a role, you can specify the duration of your role session with the DurationSeconds parameter. You can specify a parameter value of up to 43200 seconds (12 hours), depending on the maximum session duration setting for your role. However, if you assume a role using role chaining and provide a DurationSeconds parameter value greater than one hour, the operation fails.   Permissions  The temporary security credentials created by AssumeRoleWithSAML can be used to make API calls to any Amazon Web Services service with the following exception: you cannot call the STS GetFederationToken or GetSessionToken API operations. (Optional) You can pass inline or managed session policies to this operation. You can pass a single JSON policy document to use as an inline session policy. You can also specify up to 10 managed policies to use as managed session policies. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. Calling AssumeRoleWithSAML does not require the use of Amazon Web Services security credentials. The identity of the caller is validated by using keys in the metadata document that is uploaded for the SAML provider entity for your identity provider.   Calling AssumeRoleWithSAML can result in an entry in your CloudTrail logs. The entry includes the value in the NameID element of the SAML assertion. We recommend that you use a NameIDType that is not associated with any personally identifiable information (PII). For example, you could instead use the persistent identifier (urn:oasis:names:tc:SAML:2.0:nameid-format:persistent).   Tags  (Optional) You can configure your IdP to pass attributes into your SAML assertion as session tags. Each session tag consists of a key name and an associated value. For more information about session tags, see Passing Session Tags in STS in the IAM User Guide. You can pass up to 50 session tags. The plaintext session tag keys can’t exceed 128 characters and the values can’t exceed 256 characters. For these and additional limits, see IAM and STS Character Limits in the IAM User Guide.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   You can pass a session tag with the same key as a tag that is attached to the role. When you do, session tags override the role's tags with the same key. An administrator must grant you the permissions necessary to pass session tags. The administrator can also create granular permissions to allow you to pass only specific session tags. For more information, see Tutorial: Using Tags for Attribute-Based Access Control in the IAM User Guide. You can set the session tags as transitive. Transitive tags persist during role chaining. For more information, see Chaining Roles with Session Tags in the IAM User Guide.  SAML Configuration  Before your application can call AssumeRoleWithSAML, you must configure your SAML identity provider (IdP) to issue the claims required by Amazon Web Services. Additionally, you must use Identity and Access Management (IAM) to create a SAML provider entity in your Amazon Web Services account that represents your identity provider. You must also create an IAM role that specifies this SAML provider in its trust policy.  For more information, see the following resources:    About SAML 2.0-based Federation in the IAM User Guide.     Creating SAML Identity Providers in the IAM User Guide.     Configuring a Relying Party and Claims in the IAM User Guide.     Creating a Role for SAML 2.0 Federation in the IAM User Guide.

    Args:
        role_arn(str): The Amazon Resource Name (ARN) of the role that the caller is assuming.
        principal_arn(str): The Amazon Resource Name (ARN) of the SAML provider in IAM that describes the IdP.
        saml_assertion(str): The base64 encoded SAML authentication response provided by the IdP. For more information, see Configuring a Relying Party and Adding Claims in the IAM User Guide. .
        policy_arns(List, optional): The Amazon Resource Names (ARNs) of the IAM managed policies that you want to use as managed session policies. The policies must exist in the same account as the role. This parameter is optional. You can provide up to 10 managed policy ARNs. However, the plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. Defaults to None.
        policy(str, optional): An IAM policy in JSON format that you want to use as an inline session policy. This parameter is optional. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide.  The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. The JSON policy characters can be any ASCII character from the space character to the end of the valid character list (\u0020 through \u00FF). It can also include the tab (\u0009), linefeed (\u000A), and carriage return (\u000D) characters.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.  . Defaults to None.
        duration_seconds(int, optional): The duration, in seconds, of the role session. Your role session lasts for the duration that you specify for the DurationSeconds parameter, or until the time specified in the SAML authentication response's SessionNotOnOrAfter value, whichever is shorter. You can provide a DurationSeconds value from 900 seconds (15 minutes) up to the maximum session duration setting for the role. This setting can have a value from 1 hour to 12 hours. If you specify a value higher than this setting, the operation fails. For example, if you specify a session duration of 12 hours, but your administrator set the maximum session duration to 6 hours, your operation fails. To learn how to view the maximum value for your role, see View the Maximum Session Duration Setting for a Role in the IAM User Guide. By default, the value is set to 3600 seconds.   The DurationSeconds parameter is separate from the duration of a console session that you might request using the returned credentials. The request to the federation endpoint for a console sign-in token takes a SessionDuration parameter that specifies the maximum length of the console session. For more information, see Creating a URL that Enables Federated Users to Access the Management Console in the IAM User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.role.with_.saml.assume(
                ctx, role_arn=value, principal_arn=value, saml_assertion=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.role.with_.saml.assume role_arn=value, principal_arn=value, saml_assertion=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sts",
        operation="assume_role_with_saml",
        op_kwargs={
            "RoleArn": role_arn,
            "PrincipalArn": principal_arn,
            "SAMLAssertion": saml_assertion,
            "PolicyArns": policy_arns,
            "Policy": policy,
            "DurationSeconds": duration_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, gateway_arn: str, disk_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Configures one or more gateway local disks as cache for a gateway. This operation is only supported in the cached volume, tape, and file gateway type (see How Storage Gateway works (architecture). In the request, you specify the gateway Amazon Resource Name (ARN) to which you want to add cache, and one or more disk IDs that you want to configure as cache.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        disk_ids(List): An array of strings that identify disks that are to be configured as working storage. Each string has a minimum length of 1 and maximum length of 300. You can get the disk IDs from the ListLocalDisks API.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cache.add(ctx, gateway_arn=value, disk_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cache.add gateway_arn=value, disk_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="add_cache",
        op_kwargs={"GatewayARN": gateway_arn, "DiskIds": disk_ids},
    )


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the cache of a gateway. This operation is only supported in the cached volume, tape, and file gateway types. The response includes disk IDs that are configured as cache, and it includes the amount of cache allocated and used.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cache.describe(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cache.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_cache",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def refresh(
    hub, ctx, file_share_arn: str, folder_list: List = None, recursive: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Refreshes the cached inventory of objects for the specified file share. This operation finds objects in the Amazon S3 bucket that were added, removed, or replaced since the gateway last listed the bucket's contents and cached the results. This operation does not import files into the S3 File Gateway cache storage. It only updates the cached inventory to reflect changes in the inventory of the objects in the S3 bucket. This operation is only supported in the S3 File Gateway types. You can subscribe to be notified through an Amazon CloudWatch event when your RefreshCache operation completes. For more information, see Getting notified about file operations in the Storage Gateway User Guide. This operation is Only supported for S3 File Gateways. When this API is called, it only initiates the refresh operation. When the API call completes and returns a success code, it doesn't necessarily mean that the file refresh has completed. You should use the refresh-complete notification to determine that the operation has completed before you check for new files on the gateway file share. You can subscribe to be notified through a CloudWatch event when your RefreshCache operation completes. Throttle limit: This API is asynchronous, so the gateway will accept no more than two refreshes at any time. We recommend using the refresh-complete CloudWatch event notification before issuing additional requests. For more information, see Getting notified about file operations in the Storage Gateway User Guide. If you invoke the RefreshCache API when two requests are already being processed, any new request will cause an InvalidGatewayRequestException error because too many requests were sent to the server. For more information, see Getting notified about file operations in the Storage Gateway User Guide.

    Args:
        file_share_arn(str): The Amazon Resource Name (ARN) of the file share you want to refresh.
        folder_list(List, optional): A comma-separated list of the paths of folders to refresh in the cache. The default is ["/"]. The default refreshes objects and folders at the root of the Amazon S3 bucket. If Recursive is set to true, the entire S3 bucket that the file share has access to is refreshed. Defaults to None.
        recursive(bool, optional): A value that specifies whether to recursively refresh folders in the cache. The refresh includes folders that were in the cache the last time the gateway listed the folder's contents. If this value set to true, each folder that is listed in FolderList is recursively updated. Otherwise, subfolders listed in FolderList are not refreshed. Only objects that are in folders listed directly under FolderList are found and used for the update. The default is true. Valid Values: true | false . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cache.refresh(ctx, file_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cache.refresh file_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="refresh_cache",
        op_kwargs={
            "FileShareARN": file_share_arn,
            "FolderList": folder_list,
            "Recursive": recursive,
        },
    )


async def reset(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Resets all cache disks that have encountered an error and makes the disks available for reconfiguration as cache storage. If your cache disk encounters an error, the gateway prevents read and write operations on virtual tapes in the gateway. For example, an error can occur when a disk is corrupted or removed from the gateway. When a cache is reset, the gateway loses its cache storage. At this point, you can reconfigure the disks as cache disks. This operation is only supported in the cached volume and tape types.  If the cache disk you are resetting contains data that has not been uploaded to Amazon S3 yet, that data can be lost. After you reset cache disks, there will be no configured cache disks left in the gateway, so you must configure at least one new cache disk for your gateway to function properly.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cache.reset(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cache.reset gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="reset_cache",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    core_device_thing_name: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of the components that a Greengrass core device runs.

    Args:
        core_device_thing_name(str): The name of the core device. This is also the name of the IoT thing.
        max_results(int, optional): The maximum number of results to be returned per paginated request. Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.installed_component.list_all(
                ctx, core_device_thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.installed_component.list_all core_device_thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="list_installed_components",
        op_kwargs={
            "coreDeviceThingName": core_device_thing_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    gateway_arn: str,
    tape_size_in_bytes: int,
    client_token: str,
    num_tapes_to_create: int,
    tape_barcode_prefix: str,
    kms_encrypted: bool = None,
    kms_key: str = None,
    pool_id: str = None,
    worm: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more virtual tapes. You write data to the virtual tapes and then archive the tapes. This operation is only supported in the tape gateway type.  Cache storage must be allocated to the gateway before you can create virtual tapes. Use the AddCache operation to add cache storage to a gateway.

    Args:
        gateway_arn(str): The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tapes with. Use the ListGateways operation to return a list of gateways for your account and Region.
        tape_size_in_bytes(int): The size, in bytes, of the virtual tapes that you want to create.  The size must be aligned by gigabyte (1024*1024*1024 bytes). .
        client_token(str): A unique identifier that you use to retry a request. If you retry a request, use the same ClientToken you specified in the initial request.  Using the same ClientToken prevents creating the tape multiple times. .
        num_tapes_to_create(int): The number of virtual tapes that you want to create.
        tape_barcode_prefix(str): A prefix that you append to the barcode of the virtual tape you are creating. This prefix makes the barcode unique.  The prefix must be 1-4 characters in length and must be one of the uppercase letters from A to Z. .
        kms_encrypted(bool, optional): Set to true to use Amazon S3 server-side encryption with your own KMS key, or false to use a key managed by Amazon S3. Optional. Valid Values: true | false . Defaults to None.
        kms_key(str, optional): The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value can only be set when KMSEncrypted is true. Optional. Defaults to None.
        pool_id(str, optional): The ID of the pool that you want to add your tape to for archiving. The tape in this pool is archived in the S3 storage class that is associated with the pool. When you use your backup application to eject the tape, the tape is archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive) that corresponds to the pool. Valid Values: GLACIER | DEEP_ARCHIVE . Defaults to None.
        worm(bool, optional): Set to TRUE if the tape you are creating is to be configured as a write-once-read-many (WORM) tape. Defaults to None.
        tags(List, optional): A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.init.create_multiple(
                ctx,
                gateway_arn=value,
                tape_size_in_bytes=value,
                client_token=value,
                num_tapes_to_create=value,
                tape_barcode_prefix=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.init.create_multiple gateway_arn=value, tape_size_in_bytes=value, client_token=value, num_tapes_to_create=value, tape_barcode_prefix=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_tapes",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "TapeSizeInBytes": tape_size_in_bytes,
            "ClientToken": client_token,
            "NumTapesToCreate": num_tapes_to_create,
            "TapeBarcodePrefix": tape_barcode_prefix,
            "KMSEncrypted": kms_encrypted,
            "KMSKey": kms_key,
            "PoolId": pool_id,
            "Worm": worm,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, gateway_arn: str, tape_arn: str, bypass_governance_retention: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified virtual tape. This operation is only supported in the tape gateway type.

    Args:
        gateway_arn(str): The unique Amazon Resource Name (ARN) of the gateway that the virtual tape to delete is associated with. Use the ListGateways operation to return a list of gateways for your account and Region.
        tape_arn(str): The Amazon Resource Name (ARN) of the virtual tape to delete.
        bypass_governance_retention(bool, optional): Set to TRUE to delete an archived tape that belongs to a custom pool with tape retention lock. Only archived tapes with tape retention lock set to governance can be deleted. Archived tapes with tape retention lock set to compliance can't be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.init.delete(
                ctx, gateway_arn=value, tape_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.init.delete gateway_arn=value, tape_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_tape",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "TapeARN": tape_arn,
            "BypassGovernanceRetention": bypass_governance_retention,
        },
    )


async def describe_all(
    hub,
    ctx,
    gateway_arn: str,
    tape_ar_ns: List = None,
    marker: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of the specified Amazon Resource Name (ARN) of virtual tapes. If a TapeARN is not specified, returns a description of all virtual tapes associated with the specified gateway. This operation is only supported in the tape gateway type.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        tape_ar_ns(List, optional): Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe. If this parameter is not specified, Tape gateway returns a description of all virtual tapes associated with the specified gateway. Defaults to None.
        marker(str, optional): A marker value, obtained in a previous call to DescribeTapes. This marker indicates which page of results to retrieve. If not specified, the first page of results is retrieved. Defaults to None.
        limit(int, optional): Specifies that the number of virtual tapes described be limited to the specified number.  Amazon Web Services may impose its own limit, if this field is not set. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.init.describe_all(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.init.describe_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_tapes",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "TapeARNs": tape_ar_ns,
            "Marker": marker,
            "Limit": limit,
        },
    )


async def list_all(
    hub, ctx, tape_ar_ns: List = None, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists virtual tapes in your virtual tape library (VTL) and your virtual tape shelf (VTS). You specify the tapes to list by specifying one or more tape Amazon Resource Names (ARNs). If you don't specify a tape ARN, the operation lists all virtual tapes in both your VTL and VTS. This operation supports pagination. By default, the operation returns a maximum of up to 100 tapes. You can optionally specify the Limit parameter in the body to limit the number of tapes in the response. If the number of tapes returned in the response is truncated, the response includes a Marker element that you can use in your subsequent request to retrieve the next set of tapes. This operation is only supported in the tape gateway type.

    Args:
        tape_ar_ns(List, optional): The Amazon Resource Name (ARN) of each of the tapes you want to list. If you don't specify a tape ARN, the response lists all tapes in both your VTL and VTS. Defaults to None.
        marker(str, optional): A string that indicates the position at which to begin the returned list of tapes. Defaults to None.
        limit(int, optional): An optional number limit for the tapes in the list returned by this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_tapes",
        op_kwargs={"TapeARNs": tape_ar_ns, "Marker": marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    task_id: str,
    task_status: str,
    error_id: str = None,
    error_message: str = None,
    error_stack_trace: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Task runners call SetTaskStatus to notify AWS Data Pipeline that a task is completed and provide information about the final status. A task runner makes this call regardless of whether the task was sucessful. A task runner does not need to call SetTaskStatus for tasks that are canceled by the web service during a call to ReportTaskProgress.

    Args:
        task_id(str): The ID of the task assigned to the task runner. This value is provided in the response for PollForTask.
        task_status(str): If FINISHED, the task successfully completed. If FAILED, the task ended unsuccessfully. Preconditions use false.
        error_id(str, optional): If an error occurred during the task, this value specifies the error code. This value is set on the physical attempt object. It is used to display error information to the user. It should not start with string "Service_" which is reserved by the system. Defaults to None.
        error_message(str, optional): If an error occurred during the task, this value specifies a text description of the error. This value is set on the physical attempt object. It is used to display error information to the user. The web service does not parse this value. Defaults to None.
        error_stack_trace(str, optional): If an error occurred during the task, this value specifies the stack trace associated with the error. This value is set on the physical attempt object. It is used to display error information to the user. The web service does not parse this value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.task.status.set(
                ctx, task_id=value, task_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.task.status.set task_id=value, task_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="set_task_status",
        op_kwargs={
            "taskId": task_id,
            "taskStatus": task_status,
            "errorId": error_id,
            "errorMessage": error_message,
            "errorStackTrace": error_stack_trace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, retention_configuration_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the retention configuration.

    Args:
        retention_configuration_name(str): The name of the retention configuration to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.retention_configuration.delete(
                ctx, retention_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.retention_configuration.delete retention_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_retention_configuration",
        op_kwargs={"RetentionConfigurationName": retention_configuration_name},
    )


async def describe_all(
    hub, ctx, retention_configuration_names: List = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of one or more retention configurations. If the retention configuration name is not specified, this action returns the details for all the retention configurations for that account.  Currently, AWS Config supports only one retention configuration per region in your account.

    Args:
        retention_configuration_names(List, optional): A list of names of retention configurations for which you want details. If you do not specify a name, AWS Config returns details for all the retention configurations for that account.  Currently, AWS Config supports only one retention configuration per region in your account. . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.retention_configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.retention_configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_retention_configurations",
        op_kwargs={
            "RetentionConfigurationNames": retention_configuration_names,
            "NextToken": next_token,
        },
    )


async def put(hub, ctx, retention_period_in_days: int) -> Dict:
    r"""
    **Autogenerated function**

    Creates and updates the retention configuration with details about retention period (number of days) that AWS Config stores your historical information. The API creates the RetentionConfiguration object and names the object as default. When you have a RetentionConfiguration object named default, calling the API modifies the default object.   Currently, AWS Config supports only one retention configuration per region in your account.

    Args:
        retention_period_in_days(int): Number of days AWS Config stores your historical information.  Currently, only applicable to the configuration item history. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.retention_configuration.put(
                ctx, retention_period_in_days=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.retention_configuration.put retention_period_in_days=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_retention_configuration",
        op_kwargs={"RetentionPeriodInDays": retention_period_in_days},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    resource_type: str,
    resource_ids: List = None,
    resource_name: str = None,
    limit: int = None,
    include_deleted_resources: bool = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a resource type and returns a list of resource identifiers for the resources of that type. A resource identifier includes the resource type, ID, and (if available) the custom resource name. The results consist of resources that AWS Config has discovered, including those that AWS Config is not currently recording. You can narrow the results to include only resources that have specific resource IDs or a resource name.  You can specify either resource IDs or a resource name, but not both, in the same request.  The response is paginated. By default, AWS Config lists 100 resource identifiers on each page. You can customize this number with the limit parameter. The response includes a nextToken string. To get the next page of results, run the request again and specify the string for the nextToken parameter.

    Args:
        resource_type(str): The type of resources that you want AWS Config to list in the response.
        resource_ids(List, optional): The IDs of only those resources that you want AWS Config to list in the response. If you do not specify this parameter, AWS Config lists all resources of the specified type that it has discovered. Defaults to None.
        resource_name(str, optional): The custom name of only those resources that you want AWS Config to list in the response. If you do not specify this parameter, AWS Config lists all resources of the specified type that it has discovered. Defaults to None.
        limit(int, optional): The maximum number of resource identifiers returned on each page. The default is 100. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        include_deleted_resources(bool, optional): Specifies whether AWS Config includes deleted resources in the results. By default, deleted resources are not included. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.discovered_resource.init.list_all(
                ctx, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.discovered_resource.init.list_all resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="list_discovered_resources",
        op_kwargs={
            "resourceType": resource_type,
            "resourceIds": resource_ids,
            "resourceName": resource_name,
            "limit": limit,
            "includeDeletedResources": include_deleted_resources,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, domain_name: str, uri: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an integration from a specific domain.

    Args:
        domain_name(str): The unique name of the domain.
        uri(str): The URI of the S3 bucket or any other type of data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.integration.delete(
                ctx, domain_name=value, uri=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.integration.delete domain_name=value, uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_integration",
        op_kwargs={"DomainName": domain_name, "Uri": uri},
    )


async def get(hub, ctx, domain_name: str, uri: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns an integration for a domain.

    Args:
        domain_name(str): The unique name of the domain.
        uri(str): The URI of the S3 bucket or any other type of data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.integration.get(
                ctx, domain_name=value, uri=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.integration.get domain_name=value, uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="get_integration",
        op_kwargs={"DomainName": domain_name, "Uri": uri},
    )


async def list_all(
    hub, ctx, domain_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the integrations in your domain.

    Args:
        domain_name(str): The unique name of the domain.
        next_token(str, optional): The pagination token from the previous ListIntegrations API call. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.integration.list_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.integration.list_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_integrations",
        op_kwargs={
            "DomainName": domain_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put(
    hub,
    ctx,
    domain_name: str,
    object_type_name: str,
    uri: str = None,
    tags: Dict = None,
    flow_definition: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an integration between the service and a third-party service, which includes Amazon AppFlow and Amazon Connect. An integration can belong to only one domain.

    Args:
        domain_name(str): The unique name of the domain.
        uri(str, optional): The URI of the S3 bucket or any other type of data source. Defaults to None.
        object_type_name(str): The name of the profile object type.
        tags(Dict, optional): The tags used to organize, track, or control access for this resource. Defaults to None.
        flow_definition(Dict, optional): The configuration that controls how Customer Profiles retrieves data from the source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.integration.put(
                ctx, domain_name=value, object_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.integration.put domain_name=value, object_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="put_integration",
        op_kwargs={
            "DomainName": domain_name,
            "Uri": uri,
            "ObjectTypeName": object_type_name,
            "Tags": tags,
            "FlowDefinition": flow_definition,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def create(
    hub,
    ctx,
    name: str,
    protocol_type: str,
    api_key_selection_expression: str = None,
    cors_configuration: Dict = None,
    credentials_arn: str = None,
    description: str = None,
    disable_schema_validation: bool = None,
    disable_execute_api_endpoint: bool = None,
    route_key: str = None,
    route_selection_expression: str = None,
    tags: Dict = None,
    target: str = None,
    version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Api resource.

    Args:
        api_key_selection_expression(str, optional): An API key selection expression. Supported only for WebSocket APIs. See API Key Selection Expressions. Defaults to None.
        cors_configuration(Dict, optional): A CORS configuration. Supported only for HTTP APIs. See Configuring CORS for more information. Defaults to None.
        credentials_arn(str, optional): This property is part of quick create. It specifies the credentials required for the integration, if any. For a Lambda integration, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify arn:aws:iam::*:user/*. To use resource-based permissions on supported AWS services, specify null. Currently, this property is not used for HTTP integrations. Supported only for HTTP APIs. Defaults to None.
        description(str, optional): The description of the API. Defaults to None.
        disable_schema_validation(bool, optional): Avoid validating models when creating a deployment. Supported only for WebSocket APIs. Defaults to None.
        disable_execute_api_endpoint(bool, optional): Specifies whether clients can invoke your API by using the default execute-api endpoint. By default, clients can invoke your API with the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To require that clients use a custom domain name to invoke your API, disable the default endpoint. Defaults to None.
        name(str): The name of the API.
        protocol_type(str): The API protocol.
        route_key(str, optional): This property is part of quick create. If you don't specify a routeKey, a default route of $default is created. The $default route acts as a catch-all for any request made to your API, for a particular stage. The $default route key can't be modified. You can add routes after creating the API, and you can update the route keys of additional routes. Supported only for HTTP APIs. Defaults to None.
        route_selection_expression(str, optional): The route selection expression for the API. For HTTP APIs, the routeSelectionExpression must be ${request.method} ${request.path}. If not provided, this will be the default for HTTP APIs. This property is required for WebSocket APIs. Defaults to None.
        tags(Dict, optional): The collection of tags. Each tag element is associated with a given resource. Defaults to None.
        target(str, optional): This property is part of quick create. Quick create produces an API with an integration, a default catch-all route, and a default stage which is configured to automatically deploy changes. For HTTP integrations, specify a fully qualified URL. For Lambda integrations, specify a function ARN. The type of the integration will be HTTP_PROXY or AWS_PROXY, respectively. Supported only for HTTP APIs. Defaults to None.
        version(str, optional): A version identifier for the API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.create(ctx, name=value, protocol_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.create name=value, protocol_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_api",
        op_kwargs={
            "ApiKeySelectionExpression": api_key_selection_expression,
            "CorsConfiguration": cors_configuration,
            "CredentialsArn": credentials_arn,
            "Description": description,
            "DisableSchemaValidation": disable_schema_validation,
            "DisableExecuteApiEndpoint": disable_execute_api_endpoint,
            "Name": name,
            "ProtocolType": protocol_type,
            "RouteKey": route_key,
            "RouteSelectionExpression": route_selection_expression,
            "Tags": tags,
            "Target": target,
            "Version": version,
        },
    )


async def delete(hub, ctx, api_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Api resource.

    Args:
        api_id(str): The API identifier.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.delete(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.delete api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_api",
        op_kwargs={"ApiId": api_id},
    )


async def export(
    hub,
    ctx,
    api_id: str,
    output_type: str,
    specification: str,
    export_version: str = None,
    include_extensions: bool = None,
    stage_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        api_id(str): The API identifier.
        export_version(str, optional): The version of the API Gateway export algorithm. API Gateway uses the latest version by default. Currently, the only supported version is 1.0. Defaults to None.
        include_extensions(bool, optional): Specifies whether to include API Gateway extensions in the exported API definition. API Gateway extensions are included by default. Defaults to None.
        output_type(str): The output type of the exported definition file. Valid values are JSON and YAML.
        specification(str): The version of the API specification to use. OAS30, for OpenAPI 3.0, is the only supported value.
        stage_name(str, optional): The name of the API stage to export. If you don't specify this property, a representation of the latest API configuration is exported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.export(ctx, api_id=value, output_type=value, specification=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.export api_id=value, output_type=value, specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="export_api",
        op_kwargs={
            "ApiId": api_id,
            "ExportVersion": export_version,
            "IncludeExtensions": include_extensions,
            "OutputType": output_type,
            "Specification": specification,
            "StageName": stage_name,
        },
    )


async def get(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Api resource.

    Args:
        api_id(str): The API identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.get(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.get api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_api",
        op_kwargs={"ApiId": api_id},
    )


async def import_(
    hub, ctx, body: str, basepath: str = None, fail_on_warnings: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Imports an API.

    Args:
        basepath(str, optional): Specifies how to interpret the base path of the API during import. Valid values are ignore, prepend, and split. The default value is ignore. To learn more, see Set the OpenAPI basePath Property. Supported only for HTTP APIs. Defaults to None.
        body(str): The OpenAPI definition. Supported only for HTTP APIs.
        fail_on_warnings(bool, optional): Specifies whether to rollback the API creation when a warning is encountered. By default, API creation continues if a warning is encountered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.import(ctx, body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.import body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="import_api",
        op_kwargs={
            "Basepath": basepath,
            "Body": body,
            "FailOnWarnings": fail_on_warnings,
        },
    )


async def reimport(
    hub,
    ctx,
    api_id: str,
    body: str,
    basepath: str = None,
    fail_on_warnings: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Puts an Api resource.

    Args:
        api_id(str): The API identifier.
        basepath(str, optional): Specifies how to interpret the base path of the API during import. Valid values are ignore, prepend, and split. The default value is ignore. To learn more, see Set the OpenAPI basePath Property. Supported only for HTTP APIs. Defaults to None.
        body(str): The OpenAPI definition. Supported only for HTTP APIs.
        fail_on_warnings(bool, optional): Specifies whether to rollback the API creation when a warning is encountered. By default, API creation continues if a warning is encountered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.reimport(ctx, api_id=value, body=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.reimport api_id=value, body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="reimport_api",
        op_kwargs={
            "ApiId": api_id,
            "Basepath": basepath,
            "Body": body,
            "FailOnWarnings": fail_on_warnings,
        },
    )


async def update(
    hub,
    ctx,
    api_id: str,
    api_key_selection_expression: str = None,
    cors_configuration: Dict = None,
    credentials_arn: str = None,
    description: str = None,
    disable_schema_validation: bool = None,
    disable_execute_api_endpoint: bool = None,
    name: str = None,
    route_key: str = None,
    route_selection_expression: str = None,
    target: str = None,
    version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Api resource.

    Args:
        api_id(str): The API identifier.
        api_key_selection_expression(str, optional): An API key selection expression. Supported only for WebSocket APIs. See API Key Selection Expressions. Defaults to None.
        cors_configuration(Dict, optional): A CORS configuration. Supported only for HTTP APIs. Defaults to None.
        credentials_arn(str, optional): This property is part of quick create. It specifies the credentials required for the integration, if any. For a Lambda integration, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify arn:aws:iam::*:user/*. To use resource-based permissions on supported AWS services, don't specify this parameter. Currently, this property is not used for HTTP integrations. If provided, this value replaces the credentials associated with the quick create integration. Supported only for HTTP APIs. Defaults to None.
        description(str, optional): The description of the API. Defaults to None.
        disable_schema_validation(bool, optional): Avoid validating models when creating a deployment. Supported only for WebSocket APIs. Defaults to None.
        disable_execute_api_endpoint(bool, optional): Specifies whether clients can invoke your API by using the default execute-api endpoint. By default, clients can invoke your API with the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To require that clients use a custom domain name to invoke your API, disable the default endpoint. Defaults to None.
        name(str, optional): The name of the API. Defaults to None.
        route_key(str, optional): This property is part of quick create. If not specified, the route created using quick create is kept. Otherwise, this value replaces the route key of the quick create route. Additional routes may still be added after the API is updated. Supported only for HTTP APIs. Defaults to None.
        route_selection_expression(str, optional): The route selection expression for the API. For HTTP APIs, the routeSelectionExpression must be ${request.method} ${request.path}. If not provided, this will be the default for HTTP APIs. This property is required for WebSocket APIs. Defaults to None.
        target(str, optional): This property is part of quick create. For HTTP integrations, specify a fully qualified URL. For Lambda integrations, specify a function ARN. The type of the integration will be HTTP_PROXY or AWS_PROXY, respectively. The value provided updates the integration URI and integration type. You can update a quick-created target, but you can't remove it from an API. Supported only for HTTP APIs. Defaults to None.
        version(str, optional): A version identifier for the API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.init.update(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.init.update api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_api",
        op_kwargs={
            "ApiId": api_id,
            "ApiKeySelectionExpression": api_key_selection_expression,
            "CorsConfiguration": cors_configuration,
            "CredentialsArn": credentials_arn,
            "Description": description,
            "DisableSchemaValidation": disable_schema_validation,
            "DisableExecuteApiEndpoint": disable_execute_api_endpoint,
            "Name": name,
            "RouteKey": route_key,
            "RouteSelectionExpression": route_selection_expression,
            "Target": target,
            "Version": version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    endpoint_config_name: str,
    production_variants: List,
    data_capture_config: Dict = None,
    tags: List = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint configuration that Amazon SageMaker hosting services uses to deploy models. In the configuration, you identify one or more models, created using the CreateModel API, to deploy and the resources that you want Amazon SageMaker to provision. Then you call the CreateEndpoint API.   Use this API if you want to use Amazon SageMaker hosting services to deploy models into production.   In the request, you define a ProductionVariant, for each model that you want to deploy. Each ProductionVariant parameter also describes the resources that you want Amazon SageMaker to provision. This includes the number and type of ML compute instances to deploy.  If you are hosting multiple models, you also assign a VariantWeight to specify how much traffic you want to allocate to each model. For example, suppose that you want to host two models, A and B, and you assign traffic weight 2 for model A and 1 for model B. Amazon SageMaker distributes two-thirds of the traffic to Model A, and one-third to model B.  For an example that calls this method when deploying a model to Amazon SageMaker hosting services, see Deploy the Model to Amazon SageMaker Hosting Services (Amazon Web Services SDK for Python (Boto 3)).   When you call CreateEndpoint, a load call is made to DynamoDB to verify that your endpoint configuration exists. When you read data from a DynamoDB table supporting  Eventually Consistent Reads , the response might not reflect the results of a recently completed write operation. The response might include some stale data. If the dependent entities are not yet in DynamoDB, this causes a validation error. If you repeat your read request after a short time, the response should return the latest data. So retry logic is recommended to handle these possible issues. We also recommend that customers call DescribeEndpointConfig before calling CreateEndpoint to minimize the potential impact of a DynamoDB eventually consistent read.

    Args:
        endpoint_config_name(str): The name of the endpoint configuration. You specify this name in a CreateEndpoint request. .
        production_variants(List): An list of ProductionVariant objects, one for each model that you want to host at this endpoint.
        data_capture_config(Dict, optional): . Defaults to None.
        tags(List, optional): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources. Defaults to None.
        kms_key_id(str, optional): The Amazon Resource Name (ARN) of a Amazon Web Services Key Management Service key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance that hosts the endpoint. The KmsKeyId can be any of the following formats:    Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias name ARN: arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias    The KMS key policy must grant permission to the IAM role that you specify in your CreateEndpoint, UpdateEndpoint requests. For more information, refer to the Amazon Web Services Key Management Service section Using Key Policies in Amazon Web Services KMS    Certain Nitro-based instances include local storage, dependent on the instance type. Local storage volumes are encrypted using a hardware module on the instance. You can't request a KmsKeyId when using an instance type with local storage. If any of the models that you specify in the ProductionVariants parameter use nitro-based instances with local storage, do not specify a value for the KmsKeyId parameter. If you specify a value for KmsKeyId when using any nitro-based instances with local storage, the call to CreateEndpointConfig fails. For a list of instance types that support local instance storage, see Instance Store Volumes. For more information about local instance storage encryption, see SSD Instance Store Volumes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.config.create(
                ctx, endpoint_config_name=value, production_variants=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.config.create endpoint_config_name=value, production_variants=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_endpoint_config",
        op_kwargs={
            "EndpointConfigName": endpoint_config_name,
            "ProductionVariants": production_variants,
            "DataCaptureConfig": data_capture_config,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
        },
    )


async def delete(hub, ctx, endpoint_config_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an endpoint configuration. The DeleteEndpointConfig API deletes only the specified configuration. It does not delete endpoints created using the configuration.  You must not delete an EndpointConfig in use by an endpoint that is live or while the UpdateEndpoint or CreateEndpoint operations are being performed on the endpoint. If you delete the EndpointConfig of an endpoint that is active or being created or updated you may lose visibility into the instance type the endpoint is using. The endpoint must be deleted in order to stop incurring charges.

    Args:
        endpoint_config_name(str): The name of the endpoint configuration that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.config.delete(
                ctx, endpoint_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.config.delete endpoint_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_endpoint_config",
        op_kwargs={"EndpointConfigName": endpoint_config_name},
    )


async def describe(hub, ctx, endpoint_config_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of an endpoint configuration created using the CreateEndpointConfig API.

    Args:
        endpoint_config_name(str): The name of the endpoint configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.config.describe(
                ctx, endpoint_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.config.describe endpoint_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_endpoint_config",
        op_kwargs={"EndpointConfigName": endpoint_config_name},
    )


async def list_all(
    hub,
    ctx,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists endpoint configurations.

    Args:
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Descending. Defaults to None.
        next_token(str, optional): If the result of the previous ListEndpointConfig request was truncated, the response includes a NextToken. To retrieve the next set of endpoint configurations, use the token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of training jobs to return in the response. Defaults to None.
        name_contains(str, optional): A string in the endpoint configuration name. This filter returns only endpoint configurations whose name contains the specified string. . Defaults to None.
        creation_time_before(str, optional): A filter that returns only endpoint configurations created before the specified time (timestamp). Defaults to None.
        creation_time_after(str, optional): A filter that returns only endpoint configurations with a creation time greater than or equal to the specified time (timestamp). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.endpoint.config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.endpoint.config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_endpoint_configs",
        op_kwargs={
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    vm_server_address_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the servers in your server catalog. Before you can describe your servers, you must import them using ImportServerCatalog.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. The default value is 50. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        vm_server_address_list(List, optional): The server addresses. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.server.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.server.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="get_servers",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "vmServerAddressList": vm_server_address_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    aws_account_id: str,
    assignment_name: str,
    assignment_status: str,
    namespace: str,
    policy_arn: str = None,
    identities: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an assignment with one specified IAM policy, identified by its Amazon Resource Name (ARN). This policy assignment is attached to the specified groups or users of Amazon QuickSight. Assignment names are unique per Amazon Web Services account;. To avoid overwriting rules in other namespaces, use assignment names that are unique.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; where you want to assign an IAM policy to QuickSight users or groups.
        assignment_name(str): The name of the assignment, also called a rule. It must be unique within an Amazon Web Services account;.
        assignment_status(str): The status of the assignment. Possible values are as follows:    ENABLED - Anything specified in this assignment is used when creating the data source.    DISABLED - This assignment isn't used when creating the data source.    DRAFT - This assignment is an unfinished draft and isn't used when creating the data source.  .
        policy_arn(str, optional): The ARN for the IAM policy to apply to the QuickSight users and groups specified in this assignment. Defaults to None.
        identities(Dict, optional): The QuickSight users, groups, or both that you want to assign the policy to. Defaults to None.
        namespace(str): The namespace that contains the assignment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.init.create(
                ctx,
                aws_account_id=value,
                assignment_name=value,
                assignment_status=value,
                namespace=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.init.create aws_account_id=value, assignment_name=value, assignment_status=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_iam_policy_assignment",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AssignmentName": assignment_name,
            "AssignmentStatus": assignment_status,
            "PolicyArn": policy_arn,
            "Identities": identities,
            "Namespace": namespace,
        },
    )


async def delete(
    hub, ctx, aws_account_id: str, assignment_name: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing IAM policy assignment.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID where you want to delete the IAM policy assignment.
        assignment_name(str): The name of the assignment. .
        namespace(str): The namespace that contains the assignment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.init.delete(
                ctx, aws_account_id=value, assignment_name=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.init.delete aws_account_id=value, assignment_name=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_iam_policy_assignment",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AssignmentName": assignment_name,
            "Namespace": namespace,
        },
    )


async def describe(
    hub, ctx, aws_account_id: str, assignment_name: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing IAM policy assignment, as specified by the assignment name.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the assignment that you want to describe.
        assignment_name(str): The name of the assignment, also called a rule.
        namespace(str): The namespace that contains the assignment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.init.describe(
                ctx, aws_account_id=value, assignment_name=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.init.describe aws_account_id=value, assignment_name=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_iam_policy_assignment",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AssignmentName": assignment_name,
            "Namespace": namespace,
        },
    )


async def list_all(
    hub,
    ctx,
    aws_account_id: str,
    namespace: str,
    assignment_status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists IAM policy assignments in the current Amazon QuickSight account.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains these IAM policy assignments.
        assignment_status(str, optional): The status of the assignments. Defaults to None.
        namespace(str): The namespace for the assignments.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.init.list_all(
                ctx, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.init.list_all aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_iam_policy_assignments",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AssignmentStatus": assignment_status,
            "Namespace": namespace,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    assignment_name: str,
    namespace: str,
    assignment_status: str = None,
    policy_arn: str = None,
    identities: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing IAM policy assignment. This operation updates only the optional parameter or parameters that are specified in the request. This overwrites all of the users included in Identities.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the IAM policy assignment. .
        assignment_name(str): The name of the assignment, also called a rule. This name must be unique within an Amazon Web Services account;.
        namespace(str): The namespace of the assignment.
        assignment_status(str, optional): The status of the assignment. Possible values are as follows:    ENABLED - Anything specified in this assignment is used when creating the data source.    DISABLED - This assignment isn't used when creating the data source.    DRAFT - This assignment is an unfinished draft and isn't used when creating the data source.  . Defaults to None.
        policy_arn(str, optional): The ARN for the IAM policy to apply to the QuickSight users and groups specified in this assignment. Defaults to None.
        identities(Dict, optional): The QuickSight users, groups, or both that you want to assign the policy to. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.iam_policy_assignment.init.update(
                ctx, aws_account_id=value, assignment_name=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.iam_policy_assignment.init.update aws_account_id=value, assignment_name=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_iam_policy_assignment",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "AssignmentName": assignment_name,
            "Namespace": namespace,
            "AssignmentStatus": assignment_status,
            "PolicyArn": policy_arn,
            "Identities": identities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    firewall_name: str,
    firewall_policy_arn: str,
    vpc_id: str,
    subnet_mappings: List,
    delete_protection: bool = None,
    subnet_change_protection: bool = None,
    firewall_policy_change_protection: bool = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS Network Firewall Firewall and accompanying FirewallStatus for a VPC.  The firewall defines the configuration settings for an AWS Network Firewall firewall. The settings that you can define at creation include the firewall policy, the subnets in your VPC to use for the firewall endpoints, and any tags that are attached to the firewall AWS resource.  After you create a firewall, you can provide additional settings, like the logging configuration.  To update the settings for a firewall, you use the operations that apply to the settings themselves, for example UpdateLoggingConfiguration, AssociateSubnets, and UpdateFirewallDeleteProtection.  To manage a firewall's tags, use the standard AWS resource tagging operations, ListTagsForResource, TagResource, and UntagResource. To retrieve information about firewalls, use ListFirewalls and DescribeFirewall.

    Args:
        firewall_name(str): The descriptive name of the firewall. You can't change the name of a firewall after you create it.
        firewall_policy_arn(str): The Amazon Resource Name (ARN) of the FirewallPolicy that you want to use for the firewall.
        vpc_id(str): The unique identifier of the VPC where Network Firewall should create the firewall.  You can't change this setting after you create the firewall. .
        subnet_mappings(List): The public subnets to use for your Network Firewall firewalls. Each subnet must belong to a different Availability Zone in the VPC. Network Firewall creates a firewall endpoint in each subnet. .
        delete_protection(bool, optional): A flag indicating whether it is possible to delete the firewall. A setting of TRUE indicates that the firewall is protected against deletion. Use this setting to protect against accidentally deleting a firewall that is in use. When you create a firewall, the operation initializes this flag to TRUE. Defaults to None.
        subnet_change_protection(bool, optional): A setting indicating whether the firewall is protected against changes to the subnet associations. Use this setting to protect against accidentally modifying the subnet associations for a firewall that is in use. When you create a firewall, the operation initializes this setting to TRUE. Defaults to None.
        firewall_policy_change_protection(bool, optional): A setting indicating whether the firewall is protected against a change to the firewall policy association. Use this setting to protect against accidentally modifying the firewall policy for a firewall that is in use. When you create a firewall, the operation initializes this setting to TRUE. Defaults to None.
        description(str, optional): A description of the firewall. Defaults to None.
        tags(List, optional): The key:value pairs to associate with the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.init.create(
                ctx,
                firewall_name=value,
                firewall_policy_arn=value,
                vpc_id=value,
                subnet_mappings=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.init.create firewall_name=value, firewall_policy_arn=value, vpc_id=value, subnet_mappings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="create_firewall",
        op_kwargs={
            "FirewallName": firewall_name,
            "FirewallPolicyArn": firewall_policy_arn,
            "VpcId": vpc_id,
            "SubnetMappings": subnet_mappings,
            "DeleteProtection": delete_protection,
            "SubnetChangeProtection": subnet_change_protection,
            "FirewallPolicyChangeProtection": firewall_policy_change_protection,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, firewall_name: str = None, firewall_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Firewall and its FirewallStatus. This operation requires the firewall's DeleteProtection flag to be FALSE. You can't revert this operation.  You can check whether a firewall is in use by reviewing the route tables for the Availability Zones where you have firewall subnet mappings. Retrieve the subnet mappings by calling DescribeFirewall. You define and update the route tables through Amazon VPC. As needed, update the route tables for the zones to remove the firewall endpoints. When the route tables no longer use the firewall endpoints, you can remove the firewall safely. To delete a firewall, remove the delete protection if you need to using UpdateFirewallDeleteProtection, then delete the firewall by calling DeleteFirewall.

    Args:
        firewall_name(str, optional): The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_arn(str, optional): The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="delete_firewall",
        op_kwargs={"FirewallName": firewall_name, "FirewallArn": firewall_arn},
    )


async def describe(
    hub, ctx, firewall_name: str = None, firewall_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data objects for the specified firewall.

    Args:
        firewall_name(str, optional): The descriptive name of the firewall. You can't change the name of a firewall after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        firewall_arn(str, optional): The Amazon Resource Name (ARN) of the firewall. You must specify the ARN or the name, and you can specify both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="describe_firewall",
        op_kwargs={"FirewallName": firewall_name, "FirewallArn": firewall_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, vpc_ids: List = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs. Depending on your setting for max results and the number of firewalls, a single call might not return the full list.

    Args:
        next_token(str, optional): When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request. Defaults to None.
        vpc_ids(List, optional): The unique identifiers of the VPCs that you want Network Firewall to retrieve the firewalls for. Leave this blank to retrieve all firewalls that you have defined. Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.firewall.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.firewall.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="list_firewalls",
        op_kwargs={
            "NextToken": next_token,
            "VpcIds": vpc_ids,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    zone_names: List = None,
    zone_ids: List = None,
    all_availability_zones: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Availability Zones, Local Zones, and Wavelength Zones that are available to you. If there is an event impacting a zone, you can use this request to view the state and any provided messages for that zone. For more information about Availability Zones, Local Zones, and Wavelength Zones, see Regions, Zones and Outposts in the Amazon Elastic Compute Cloud User Guide.

    Args:
        filters(List, optional): The filters.    group-name - For Availability Zones, use the Region name. For Local Zones, use the name of the group associated with the Local Zone (for example, us-west-2-lax-1) For Wavelength Zones, use the name of the group associated with the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    message - The Zone message.    opt-in-status - The opt-in status (opted-in, and not-opted-in | opt-in-not-required).    parent-zoneID - The ID of the zone that handles some of the Local Zone and Wavelength Zone control plane operations, such as API calls.    parent-zoneName - The ID of the zone that handles some of the Local Zone and Wavelength Zone control plane operations, such as API calls.    region-name - The name of the Region for the Zone (for example, us-east-1).    state - The state of the Availability Zone, the Local Zone, or the Wavelength Zone (available | information | impaired | unavailable).    zone-id - The ID of the Availability Zone (for example, use1-az1), the Local Zone (for example, usw2-lax1-az1), or the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    zone-type - The type of zone, for example, local-zone.    zone-name - The name of the Availability Zone (for example, us-east-1a), the Local Zone (for example, us-west-2-lax-1a), or the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    zone-type - The type of zone, for example, local-zone.  . Defaults to None.
        zone_names(List, optional): The names of the Availability Zones, Local Zones, and Wavelength Zones. Defaults to None.
        zone_ids(List, optional): The IDs of the Availability Zones, Local Zones, and Wavelength Zones. Defaults to None.
        all_availability_zones(bool, optional): Include all Availability Zones, Local Zones, and Wavelength Zones regardless of your opt-in status. If you do not use this parameter, the results include only the zones for the Regions where you have chosen the option to opt in. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.availability_zone.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.availability_zone.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_availability_zones",
        op_kwargs={
            "Filters": filters,
            "ZoneNames": zone_names,
            "ZoneIds": zone_ids,
            "AllAvailabilityZones": all_availability_zones,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def validate(hub, ctx, s3_relative_path: str) -> Dict:
    r"""
    **Autogenerated function**

     Validates the integrity of an assessment report in Audit Manager.

    Args:
        s3_relative_path(str):  The relative path of the specified Amazon S3 bucket in which the assessment report is stored. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.report.integrity.validate(
                ctx, s3_relative_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.report.integrity.validate s3_relative_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="validate_assessment_report_integrity",
        op_kwargs={"s3RelativePath": s3_relative_path},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def disable(hub, ctx, alarm_names: List) -> None:
    r"""
    **Autogenerated function**

    Disables the actions for the specified alarms. When an alarm's actions are disabled, the alarm actions do not execute when the alarm state changes.

    Args:
        alarm_names(List): The names of the alarms.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.action.disable(ctx, alarm_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.action.disable alarm_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="disable_alarm_actions",
        op_kwargs={"AlarmNames": alarm_names},
    )


async def enable(hub, ctx, alarm_names: List) -> None:
    r"""
    **Autogenerated function**

    Enables the actions for the specified alarms.

    Args:
        alarm_names(List): The names of the alarms.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.action.enable(ctx, alarm_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.action.enable alarm_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="enable_alarm_actions",
        op_kwargs={"AlarmNames": alarm_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, role_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Authorizes the Shield Response Team (SRT) using the specified role, to access your Amazon Web Services account to assist with DDoS attack mitigation during potential attacks. This enables the SRT to inspect your WAF configuration and create or update WAF rules and web ACLs. You can associate only one RoleArn with your subscription. If you submit an AssociateDRTRole request for an account that already has an associated role, the new RoleArn will replace the existing RoleArn.  Prior to making the AssociateDRTRole request, you must attach the AWSShieldDRTAccessPolicy managed policy to the role you will specify in the request. For more information see Attaching and Detaching IAM Policies. The role must also trust the service principal  drt.shield.amazonaws.com. For more information, see IAM JSON Policy Elements: Principal. The SRT will have access only to your WAF and Shield resources. By submitting this request, you authorize the SRT to inspect your WAF and Shield configuration and create and update WAF rules and web ACLs on your behalf. The SRT takes these actions only if explicitly authorized by you. You must have the iam:PassRole permission to make an AssociateDRTRole request. For more information, see Granting a User Permissions to Pass a Role to an Amazon Web Services Service.  To use the services of the SRT and make an AssociateDRTRole request, you must be subscribed to the Business Support plan or the Enterprise Support plan.

    Args:
        role_arn(str): The Amazon Resource Name (ARN) of the role the SRT will use to access your Amazon Web Services account. Prior to making the AssociateDRTRole request, you must attach the AWSShieldDRTAccessPolicy managed policy to this role. For more information see Attaching and Detaching IAM Policies.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.drt.role.associate(ctx, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.drt.role.associate role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="associate_drt_role",
        op_kwargs={"RoleArn": role_arn},
    )


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Removes the Shield Response Team's (SRT) access to your Amazon Web Services account. To make a DisassociateDRTRole request, you must be subscribed to the Business Support plan or the Enterprise Support plan. However, if you are not subscribed to one of these support plans, but had been previously and had granted the SRT access to your account, you can submit a DisassociateDRTRole request to remove this access.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.drt.role.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.drt.role.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="disassociate_drt_role", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def submit(
    hub,
    ctx,
    anomaly_instance_id: str,
    profiling_group_name: str,
    type_: str,
    comment: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends feedback to CodeGuru Profiler about whether the anomaly detected by the analysis is useful or not.

    Args:
        anomaly_instance_id(str): The universally unique identifier (UUID) of the  AnomalyInstance  object that is included in the analysis data.
        comment(str, optional): Optional feedback about this anomaly. Defaults to None.
        profiling_group_name(str): The name of the profiling group that is associated with the analysis data.
        type_(str):  The feedback tpye. Thee are two valid values, Positive and Negative. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.feedback.submit(
                ctx, anomaly_instance_id=value, profiling_group_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.feedback.submit anomaly_instance_id=value, profiling_group_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="submit_feedback",
        op_kwargs={
            "anomalyInstanceId": anomaly_instance_id,
            "comment": comment,
            "profilingGroupName": profiling_group_name,
            "type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    iam_user_arn: str,
    ssh_username: str = None,
    ssh_public_key: str = None,
    allow_self_management: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new user profile.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        iam_user_arn(str): The user's IAM ARN; this can also be a federated user's ARN.
        ssh_username(str, optional): The user's SSH user name. The allowable characters are [a-z], [A-Z], [0-9], '-', and '_'. If the specified name includes other punctuation marks, AWS OpsWorks Stacks removes them. For example, my.name will be changed to myname. If you do not specify an SSH user name, AWS OpsWorks Stacks generates one from the IAM user name. . Defaults to None.
        ssh_public_key(str, optional): The user's public SSH key. Defaults to None.
        allow_self_management(bool, optional): Whether users can specify their own SSH public key through the My Settings page. For more information, see Setting an IAM User's Public SSH Key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.user_profile.create(ctx, iam_user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.user_profile.create iam_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_user_profile",
        op_kwargs={
            "IamUserArn": iam_user_arn,
            "SshUsername": ssh_username,
            "SshPublicKey": ssh_public_key,
            "AllowSelfManagement": allow_self_management,
        },
    )


async def delete(hub, ctx, iam_user_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a user profile.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        iam_user_arn(str): The user's IAM ARN. This can also be a federated user's ARN.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.user_profile.delete(ctx, iam_user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.user_profile.delete iam_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="delete_user_profile",
        op_kwargs={"IamUserArn": iam_user_arn},
    )


async def describe_all(hub, ctx, iam_user_arns: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describe specified users.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        iam_user_arns(List, optional): An array of IAM or federated user ARNs that identify the users to be described. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.user_profile.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.user_profile.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_user_profiles",
        op_kwargs={"IamUserArns": iam_user_arns},
    )


async def update(
    hub,
    ctx,
    iam_user_arn: str,
    ssh_username: str = None,
    ssh_public_key: str = None,
    allow_self_management: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a specified user profile.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        iam_user_arn(str): The user IAM ARN. This can also be a federated user's ARN.
        ssh_username(str, optional): The user's SSH user name. The allowable characters are [a-z], [A-Z], [0-9], '-', and '_'. If the specified name includes other punctuation marks, AWS OpsWorks Stacks removes them. For example, my.name will be changed to myname. If you do not specify an SSH user name, AWS OpsWorks Stacks generates one from the IAM user name. . Defaults to None.
        ssh_public_key(str, optional): The user's new SSH public key. Defaults to None.
        allow_self_management(bool, optional): Whether users can specify their own SSH public key through the My Settings page. For more information, see Managing User Permissions. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.user_profile.update(ctx, iam_user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.user_profile.update iam_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_user_profile",
        op_kwargs={
            "IamUserArn": iam_user_arn,
            "SshUsername": ssh_username,
            "SshPublicKey": ssh_public_key,
            "AllowSelfManagement": allow_self_management,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, usage_plan_id: str, key_id: str, key_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a usage plan key for adding an existing API key to a usage plan.

    Args:
        usage_plan_id(str): [Required] The Id of the UsagePlan resource representing the usage plan containing the to-be-created UsagePlanKey resource representing a plan customer.
        key_id(str): [Required] The identifier of a UsagePlanKey resource for a plan customer.
        key_type(str): [Required] The type of a UsagePlanKey resource for a plan customer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.key.create(
                ctx, usage_plan_id=value, key_id=value, key_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.key.create usage_plan_id=value, key_id=value, key_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_usage_plan_key",
        op_kwargs={"usagePlanId": usage_plan_id, "keyId": key_id, "keyType": key_type},
    )


async def delete(hub, ctx, usage_plan_id: str, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a usage plan key and remove the underlying API key from the associated usage plan.

    Args:
        usage_plan_id(str): [Required] The Id of the UsagePlan resource representing the usage plan containing the to-be-deleted UsagePlanKey resource representing a plan customer.
        key_id(str): [Required] The Id of the UsagePlanKey resource to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.key.delete(
                ctx, usage_plan_id=value, key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.key.delete usage_plan_id=value, key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_usage_plan_key",
        op_kwargs={"usagePlanId": usage_plan_id, "keyId": key_id},
    )


async def get(hub, ctx, usage_plan_id: str, key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a usage plan key of a given key identifier.

    Args:
        usage_plan_id(str): [Required] The Id of the UsagePlan resource representing the usage plan containing the to-be-retrieved UsagePlanKey resource representing a plan customer.
        key_id(str): [Required] The key Id of the to-be-retrieved UsagePlanKey resource representing a plan customer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.key.get(
                ctx, usage_plan_id=value, key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.key.get usage_plan_id=value, key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_usage_plan_key",
        op_kwargs={"usagePlanId": usage_plan_id, "keyId": key_id},
    )


async def get_all(
    hub,
    ctx,
    usage_plan_id: str,
    position: str = None,
    limit: int = None,
    name_query: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all the usage plan keys representing the API keys added to a specified usage plan.

    Args:
        usage_plan_id(str): [Required] The Id of the UsagePlan resource representing the usage plan containing the to-be-retrieved UsagePlanKey resource representing a plan customer.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.
        name_query(str, optional): A query parameter specifying the name of the to-be-returned usage plan keys. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.plan.key.get_all(ctx, usage_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.plan.key.get_all usage_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_usage_plan_keys",
        op_kwargs={
            "usagePlanId": usage_plan_id,
            "position": position,
            "limit": limit,
            "nameQuery": name_query,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    gateway_arn: str,
    volume_size_in_bytes: int,
    target_name: str,
    network_interface_id: str,
    client_token: str,
    snapshot_id: str = None,
    source_volume_arn: str = None,
    kms_encrypted: bool = None,
    kms_key: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a cached volume on a specified cached volume gateway. This operation is only supported in the cached volume gateway type.  Cache storage must be allocated to the gateway before you can create a cached volume. Use the AddCache operation to add cache storage to a gateway.  In the request, you must specify the gateway, size of the volume in bytes, the iSCSI target name, an IP address on which to expose the target, and a unique client token. In response, the gateway creates the volume and returns information about it. This information includes the volume Amazon Resource Name (ARN), its size, and the iSCSI target ARN that initiators can use to connect to the volume target. Optionally, you can provide the ARN for an existing volume as the SourceVolumeARN for this cached volume, which creates an exact copy of the existing volume’s latest recovery point. The VolumeSizeInBytes value must be equal to or larger than the size of the copied volume, in bytes.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        volume_size_in_bytes(int): The size of the volume in bytes.
        snapshot_id(str, optional): The snapshot ID (e.g. "snap-1122aabb") of the snapshot to restore as the new cached volume. Specify this field if you want to create the iSCSI storage volume from a snapshot; otherwise, do not include this field. To list snapshots for your account use DescribeSnapshots in the Amazon Elastic Compute Cloud API Reference. Defaults to None.
        target_name(str): The name of the iSCSI target used by an initiator to connect to a volume and used as a suffix for the target ARN. For example, specifying TargetName as myvolume results in the target ARN of arn:aws:storagegateway:us-east-2:111122223333:gateway/sgw-12A3456B/target/iqn.1997-05.com.amazon:myvolume. The target name must be unique across all volumes on a gateway. If you don't specify a value, Storage Gateway uses the value that was previously used for this volume as the new target name.
        source_volume_arn(str, optional): The ARN for an existing volume. Specifying this ARN makes the new volume into an exact copy of the specified existing volume's latest recovery point. The VolumeSizeInBytes value for this new volume must be equal to or larger than the size of the existing volume, in bytes. Defaults to None.
        network_interface_id(str): The network interface of the gateway on which to expose the iSCSI target. Only IPv4 addresses are accepted. Use DescribeGatewayInformation to get a list of the network interfaces available on a gateway. Valid Values: A valid IP address.
        client_token(str): A unique identifier that you use to retry a request. If you retry a request, use the same ClientToken you specified in the initial request.
        kms_encrypted(bool, optional): Set to true to use Amazon S3 server-side encryption with your own KMS key, or false to use a key managed by Amazon S3. Optional. Valid Values: true | false . Defaults to None.
        kms_key(str, optional): The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value can only be set when KMSEncrypted is true. Optional. Defaults to None.
        tags(List, optional): A list of up to 50 tags that you can assign to a cached volume. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers that you can represent in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256 characters. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cached_iscsi_volume.create(
                ctx,
                gateway_arn=value,
                volume_size_in_bytes=value,
                target_name=value,
                network_interface_id=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cached_iscsi_volume.create gateway_arn=value, volume_size_in_bytes=value, target_name=value, network_interface_id=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_cached_iscsi_volume",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "VolumeSizeInBytes": volume_size_in_bytes,
            "SnapshotId": snapshot_id,
            "TargetName": target_name,
            "SourceVolumeARN": source_volume_arn,
            "NetworkInterfaceId": network_interface_id,
            "ClientToken": client_token,
            "KMSEncrypted": kms_encrypted,
            "KMSKey": kms_key,
            "Tags": tags,
        },
    )


async def describe_all(hub, ctx, volume_ar_ns: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of the gateway volumes specified in the request. This operation is only supported in the cached volume gateway types. The list of gateway volumes in the request must be from one gateway. In the response, Storage Gateway returns volume information sorted by volume Amazon Resource Name (ARN).

    Args:
        volume_ar_ns(List): An array of strings where each string represents the Amazon Resource Name (ARN) of a cached volume. All of the specified cached volumes must be from the same gateway. Use ListVolumes to get volume ARNs for a gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.cached_iscsi_volume.describe_all(
                ctx, volume_ar_ns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.cached_iscsi_volume.describe_all volume_ar_ns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_cached_iscsi_volumes",
        op_kwargs={"VolumeARNs": volume_ar_ns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    group_id: str,
    amzn_client_token: str = None,
    connector_definition_version_arn: str = None,
    core_definition_version_arn: str = None,
    device_definition_version_arn: str = None,
    function_definition_version_arn: str = None,
    logger_definition_version_arn: str = None,
    resource_definition_version_arn: str = None,
    subscription_definition_version_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a version of a group which has already been defined.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        connector_definition_version_arn(str, optional): The ARN of the connector definition version for this group. Defaults to None.
        core_definition_version_arn(str, optional): The ARN of the core definition version for this group. Defaults to None.
        device_definition_version_arn(str, optional): The ARN of the device definition version for this group. Defaults to None.
        function_definition_version_arn(str, optional): The ARN of the function definition version for this group. Defaults to None.
        group_id(str): The ID of the Greengrass group.
        logger_definition_version_arn(str, optional): The ARN of the logger definition version for this group. Defaults to None.
        resource_definition_version_arn(str, optional): The ARN of the resource definition version for this group. Defaults to None.
        subscription_definition_version_arn(str, optional): The ARN of the subscription definition version for this group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.version.create(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.version.create group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_group_version",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "ConnectorDefinitionVersionArn": connector_definition_version_arn,
            "CoreDefinitionVersionArn": core_definition_version_arn,
            "DeviceDefinitionVersionArn": device_definition_version_arn,
            "FunctionDefinitionVersionArn": function_definition_version_arn,
            "GroupId": group_id,
            "LoggerDefinitionVersionArn": logger_definition_version_arn,
            "ResourceDefinitionVersionArn": resource_definition_version_arn,
            "SubscriptionDefinitionVersionArn": subscription_definition_version_arn,
        },
    )


async def get(hub, ctx, group_id: str, group_version_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a group version.

    Args:
        group_id(str): The ID of the Greengrass group.
        group_version_id(str): The ID of the group version. This value maps to the ''Version'' property of the corresponding ''VersionInformation'' object, which is returned by ''ListGroupVersions'' requests. If the version is the last one that was associated with a group, the value also maps to the ''LatestVersion'' property of the corresponding ''GroupInformation'' object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.version.get(
                ctx, group_id=value, group_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.version.get group_id=value, group_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_group_version",
        op_kwargs={"GroupId": group_id, "GroupVersionId": group_version_id},
    )


async def list_all(
    hub, ctx, group_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a group.

    Args:
        group_id(str): The ID of the Greengrass group.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.version.list_all(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.version.list_all group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_group_versions",
        op_kwargs={
            "GroupId": group_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str, bot_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an alias for the specified bot.  You can't delete an alias that is used in the association between a bot and a messaging channel. If an alias is used in a channel association, the DeleteBot operation returns a ResourceInUseException exception that includes a reference to the channel association that refers to the bot. You can remove the reference to the alias by deleting the channel association. If you get the same exception again, delete the referring association until the DeleteBotAlias operation is successful.

    Args:
        name(str): The name of the alias to delete. The name is case sensitive. .
        bot_name(str): The name of the bot that the alias points to.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.alias.delete(ctx, name=value, bot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.alias.delete name=value, bot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_bot_alias",
        op_kwargs={"name": name, "botName": bot_name},
    )


async def get(hub, ctx, name: str, bot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about an Amazon Lex bot alias. For more information about aliases, see versioning-aliases. This operation requires permissions for the lex:GetBotAlias action.

    Args:
        name(str): The name of the bot alias. The name is case sensitive.
        bot_name(str): The name of the bot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.alias.get(ctx, name=value, bot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.alias.get name=value, bot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bot_alias",
        op_kwargs={"name": name, "botName": bot_name},
    )


async def put(
    hub,
    ctx,
    name: str,
    bot_version: str,
    bot_name: str,
    description: str = None,
    checksum: str = None,
    conversation_logs: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alias for the specified version of the bot or replaces an alias for the specified bot. To change the version of the bot that the alias points to, replace the alias. For more information about aliases, see versioning-aliases. This operation requires permissions for the lex:PutBotAlias action.

    Args:
        name(str): The name of the alias. The name is not case sensitive.
        description(str, optional): A description of the alias. Defaults to None.
        bot_version(str): The version of the bot.
        bot_name(str): The name of the bot.
        checksum(str, optional): Identifies a specific revision of the $LATEST version. When you create a new bot alias, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception. When you want to update a bot alias, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the  checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception. Defaults to None.
        conversation_logs(Dict, optional): Settings for conversation logs for the alias. Defaults to None.
        tags(List, optional): A list of tags to add to the bot alias. You can only add tags when you create an alias, you can't use the PutBotAlias operation to update the tags on a bot alias. To update tags, use the TagResource operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.alias.put(
                ctx, name=value, bot_version=value, bot_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.alias.put name=value, bot_version=value, bot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="put_bot_alias",
        op_kwargs={
            "name": name,
            "description": description,
            "botVersion": bot_version,
            "botName": bot_name,
            "checksum": checksum,
            "conversationLogs": conversation_logs,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    source: Dict,
    artifacts: Dict,
    environment: Dict,
    service_role: str,
    description: str = None,
    secondary_sources: List = None,
    source_version: str = None,
    secondary_source_versions: List = None,
    secondary_artifacts: List = None,
    cache: Dict = None,
    timeout_in_minutes: int = None,
    queued_timeout_in_minutes: int = None,
    encryption_key: str = None,
    tags: List = None,
    vpc_config: Dict = None,
    badge_enabled: bool = None,
    logs_config: Dict = None,
    file_system_locations: List = None,
    build_batch_config: Dict = None,
    concurrent_build_limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a build project.

    Args:
        name(str): The name of the build project.
        description(str, optional): A description that makes the build project easy to identify. Defaults to None.
        source(Dict): Information about the build input source code for the build project.
        secondary_sources(List, optional): An array of ProjectSource objects. . Defaults to None.
        source_version(str, optional): A version of the build input to be built for this project. If not specified, the latest version is used. If specified, it must be one of:    For AWS CodeCommit: the commit ID, branch, or Git tag to use.   For GitHub: the commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format pr/pull-request-ID (for example pr/25). If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.   For Bitbucket: the commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.   For Amazon S3: the version ID of the object that represents the build input ZIP file to use.   If sourceVersion is specified at the build level, then that version takes precedence over this sourceVersion (at the project level).  For more information, see Source Version Sample with CodeBuild in the AWS CodeBuild User Guide. . Defaults to None.
        secondary_source_versions(List, optional): An array of ProjectSourceVersion objects. If secondarySourceVersions is specified at the build level, then they take precedence over these secondarySourceVersions (at the project level). . Defaults to None.
        artifacts(Dict): Information about the build output artifacts for the build project.
        secondary_artifacts(List, optional): An array of ProjectArtifacts objects. . Defaults to None.
        cache(Dict, optional): Stores recently used information so that it can be quickly accessed at a later time. Defaults to None.
        environment(Dict): Information about the build environment for the build project.
        service_role(str): The ARN of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
        timeout_in_minutes(int, optional): How long, in minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait before it times out any build that has not been marked as completed. The default is 60 minutes. Defaults to None.
        queued_timeout_in_minutes(int, optional): The number of minutes a build is allowed to be queued before it times out. . Defaults to None.
        encryption_key(str, optional): The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build output artifacts.  You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.   You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the format alias/<alias-name>). . Defaults to None.
        tags(List, optional): A list of tag key and value pairs associated with this build project. These tags are available for use by AWS services that support AWS CodeBuild build project tags. Defaults to None.
        vpc_config(Dict, optional): VpcConfig enables AWS CodeBuild to access resources in an Amazon VPC. Defaults to None.
        badge_enabled(bool, optional): Set this to true to generate a publicly accessible URL for your project's build badge. Defaults to None.
        logs_config(Dict, optional): Information about logs for the build project. These can be logs in Amazon CloudWatch Logs, logs uploaded to a specified S3 bucket, or both. . Defaults to None.
        file_system_locations(List, optional):  An array of ProjectFileSystemLocation objects for a CodeBuild build project. A ProjectFileSystemLocation object specifies the identifier, location, mountOptions, mountPoint, and type of a file system created using Amazon Elastic File System. . Defaults to None.
        build_batch_config(Dict, optional): A ProjectBuildBatchConfig object that defines the batch build options for the project. Defaults to None.
        concurrent_build_limit(int, optional): The maximum number of concurrent builds that are allowed for this project. New builds are only started if the current number of builds is less than or equal to this limit. If the current build count meets this limit, new builds are throttled and are not run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.project.init.create(
                ctx,
                name=value,
                source=value,
                artifacts=value,
                environment=value,
                service_role=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.project.init.create name=value, source=value, artifacts=value, environment=value, service_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="create_project",
        op_kwargs={
            "name": name,
            "description": description,
            "source": source,
            "secondarySources": secondary_sources,
            "sourceVersion": source_version,
            "secondarySourceVersions": secondary_source_versions,
            "artifacts": artifacts,
            "secondaryArtifacts": secondary_artifacts,
            "cache": cache,
            "environment": environment,
            "serviceRole": service_role,
            "timeoutInMinutes": timeout_in_minutes,
            "queuedTimeoutInMinutes": queued_timeout_in_minutes,
            "encryptionKey": encryption_key,
            "tags": tags,
            "vpcConfig": vpc_config,
            "badgeEnabled": badge_enabled,
            "logsConfig": logs_config,
            "fileSystemLocations": file_system_locations,
            "buildBatchConfig": build_batch_config,
            "concurrentBuildLimit": concurrent_build_limit,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a build project. When you delete a project, its builds are not deleted.

    Args:
        name(str): The name of the build project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.project.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.project.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_project",
        op_kwargs={"name": name},
    )


async def list_all(
    hub, ctx, sort_by: str = None, sort_order: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of build project names, with each build project name representing a single build project.

    Args:
        sort_by(str, optional): The criterion to be used to list build project names. Valid values include:    CREATED_TIME: List based on when each build project was created.    LAST_MODIFIED_TIME: List based on when information about each build project was last changed.    NAME: List based on each build project's name.   Use sortOrder to specify in what order to list the build project names based on the preceding criteria. Defaults to None.
        sort_order(str, optional): The order in which to list build projects. Valid values include:    ASCENDING: List in ascending order.    DESCENDING: List in descending order.   Use sortBy to specify the criterion to be used to list build project names. Defaults to None.
        next_token(str, optional): During a previous call, if there are more than 100 items in the list, only the first 100 items are returned, along with a unique string called a nextToken. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.project.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.project.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_projects",
        op_kwargs={"sortBy": sort_by, "sortOrder": sort_order, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    source: Dict = None,
    secondary_sources: List = None,
    source_version: str = None,
    secondary_source_versions: List = None,
    artifacts: Dict = None,
    secondary_artifacts: List = None,
    cache: Dict = None,
    environment: Dict = None,
    service_role: str = None,
    timeout_in_minutes: int = None,
    queued_timeout_in_minutes: int = None,
    encryption_key: str = None,
    tags: List = None,
    vpc_config: Dict = None,
    badge_enabled: bool = None,
    logs_config: Dict = None,
    file_system_locations: List = None,
    build_batch_config: Dict = None,
    concurrent_build_limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the settings of a build project.

    Args:
        name(str): The name of the build project.  You cannot change a build project's name. .
        description(str, optional): A new or replacement description of the build project. Defaults to None.
        source(Dict, optional): Information to be changed about the build input source code for the build project. Defaults to None.
        secondary_sources(List, optional):  An array of ProjectSource objects. . Defaults to None.
        source_version(str, optional):  A version of the build input to be built for this project. If not specified, the latest version is used. If specified, it must be one of:    For AWS CodeCommit: the commit ID, branch, or Git tag to use.   For GitHub: the commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format pr/pull-request-ID (for example pr/25). If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.   For Bitbucket: the commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.   For Amazon S3: the version ID of the object that represents the build input ZIP file to use.    If sourceVersion is specified at the build level, then that version takes precedence over this sourceVersion (at the project level).   For more information, see Source Version Sample with CodeBuild in the AWS CodeBuild User Guide. . Defaults to None.
        secondary_source_versions(List, optional):  An array of ProjectSourceVersion objects. If secondarySourceVersions is specified at the build level, then they take over these secondarySourceVersions (at the project level). . Defaults to None.
        artifacts(Dict, optional): Information to be changed about the build output artifacts for the build project. Defaults to None.
        secondary_artifacts(List, optional):  An array of ProjectSource objects. . Defaults to None.
        cache(Dict, optional): Stores recently used information so that it can be quickly accessed at a later time. Defaults to None.
        environment(Dict, optional): Information to be changed about the build environment for the build project. Defaults to None.
        service_role(str, optional): The replacement ARN of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account. Defaults to None.
        timeout_in_minutes(int, optional): The replacement value in minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait before timing out any related build that did not get marked as completed. Defaults to None.
        queued_timeout_in_minutes(int, optional):  The number of minutes a build is allowed to be queued before it times out. . Defaults to None.
        encryption_key(str, optional): The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build output artifacts.   You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.   You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the format alias/<alias-name>). . Defaults to None.
        tags(List, optional): An updated list of tag key and value pairs associated with this build project. These tags are available for use by AWS services that support AWS CodeBuild build project tags. Defaults to None.
        vpc_config(Dict, optional): VpcConfig enables AWS CodeBuild to access resources in an Amazon VPC. Defaults to None.
        badge_enabled(bool, optional): Set this to true to generate a publicly accessible URL for your project's build badge. Defaults to None.
        logs_config(Dict, optional):  Information about logs for the build project. A project can create logs in Amazon CloudWatch Logs, logs in an S3 bucket, or both. . Defaults to None.
        file_system_locations(List, optional):  An array of ProjectFileSystemLocation objects for a CodeBuild build project. A ProjectFileSystemLocation object specifies the identifier, location, mountOptions, mountPoint, and type of a file system created using Amazon Elastic File System. . Defaults to None.
        build_batch_config(Dict, optional): Contains configuration information about a batch build project. Defaults to None.
        concurrent_build_limit(int, optional): The maximum number of concurrent builds that are allowed for this project. New builds are only started if the current number of builds is less than or equal to this limit. If the current build count meets this limit, new builds are throttled and are not run. To remove this limit, set this value to -1. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.project.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.project.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="update_project",
        op_kwargs={
            "name": name,
            "description": description,
            "source": source,
            "secondarySources": secondary_sources,
            "sourceVersion": source_version,
            "secondarySourceVersions": secondary_source_versions,
            "artifacts": artifacts,
            "secondaryArtifacts": secondary_artifacts,
            "cache": cache,
            "environment": environment,
            "serviceRole": service_role,
            "timeoutInMinutes": timeout_in_minutes,
            "queuedTimeoutInMinutes": queued_timeout_in_minutes,
            "encryptionKey": encryption_key,
            "tags": tags,
            "vpcConfig": vpc_config,
            "badgeEnabled": badge_enabled,
            "logsConfig": logs_config,
            "fileSystemLocations": file_system_locations,
            "buildBatchConfig": build_batch_config,
            "concurrentBuildLimit": concurrent_build_limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    account_id: str,
    name: str,
    bucket: str,
    vpc_configuration: Dict = None,
    public_access_block_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an access point and associates it with the specified bucket. For more information, see Managing Data Access with Amazon S3 Access Points in the Amazon S3 User Guide.   S3 on Outposts only supports VPC-style access points.  For more information, see  Accessing Amazon S3 on Outposts using virtual private cloud (VPC) only access points in the Amazon S3 User Guide.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section.  The following actions are related to CreateAccessPoint:    GetAccessPoint     DeleteAccessPoint     ListAccessPoints

    Args:
        account_id(str): The account ID for the owner of the bucket for which you want to create an access point.
        name(str): The name you want to assign to this access point.
        bucket(str): The name of the bucket that you want to associate this access point with. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
        vpc_configuration(Dict, optional): If you include this field, Amazon S3 restricts access to this access point to requests from the specified virtual private cloud (VPC).  This is required for creating an access point for Amazon S3 on Outposts buckets. . Defaults to None.
        public_access_block_configuration(Dict, optional):  The PublicAccessBlock configuration that you want to apply to the access point. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.init.create(
                ctx, account_id=value, name=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.init.create account_id=value, name=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="create_access_point",
        op_kwargs={
            "AccountId": account_id,
            "Name": name,
            "Bucket": bucket,
            "VpcConfiguration": vpc_configuration,
            "PublicAccessBlockConfiguration": public_access_block_configuration,
        },
    )


async def delete(hub, ctx, account_id: str, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified access point. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to DeleteAccessPoint:    CreateAccessPoint     GetAccessPoint     ListAccessPoints

    Args:
        account_id(str): The account ID for the account that owns the specified access point.
        name(str): The name of the access point you want to delete. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the access point accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/accesspoint/<my-accesspoint-name>. For example, to access the access point reports-ap through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/accesspoint/reports-ap. The value must be URL encoded. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.init.delete(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.init.delete account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_access_point",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def get(hub, ctx, account_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns configuration information about the specified access point.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to GetAccessPoint:    CreateAccessPoint     DeleteAccessPoint     ListAccessPoints

    Args:
        account_id(str): The account ID for the account that owns the specified access point.
        name(str): The name of the access point whose configuration information you want to retrieve. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the access point accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/accesspoint/<my-accesspoint-name>. For example, to access the access point reports-ap through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/accesspoint/reports-ap. The value must be URL encoded. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.init.get(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.init.get account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_access_point",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def list_all(
    hub,
    ctx,
    account_id: str,
    bucket: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the access points currently associated with the specified bucket. You can retrieve up to 1000 access points per call. If the specified bucket has more than 1,000 access points (or the number specified in maxResults, whichever is less), the response will include a continuation token that you can use to list the additional access points.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to ListAccessPoints:    CreateAccessPoint     DeleteAccessPoint     GetAccessPoint

    Args:
        account_id(str): The account ID for owner of the bucket whose access points you want to list.
        bucket(str, optional): The name of the bucket whose associated access points you want to list. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. . Defaults to None.
        next_token(str, optional): A continuation token. If a previous call to ListAccessPoints returned a continuation token in the NextToken field, then providing that value here causes Amazon S3 to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of access points that you want to include in the list. If the specified bucket has more than this number of access points, then the response will include a continuation token in the NextToken field that you can use to retrieve the next page of access points. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.init.list_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.init.list_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="list_access_points",
        op_kwargs={
            "AccountId": account_id,
            "Bucket": bucket,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the attributes for a customer account. The attributes include Amazon RDS quotas for the account, such as the number of DB instances allowed. The description for a quota includes the quota name, current usage toward that quota, and the quota's maximum value. This command doesn't take any parameters.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.account_attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.account_attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="rds", operation="describe_account_attributes", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "filter"


async def create(hub, ctx, filter_: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new IP address filter. For information about setting up IP address filters, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        filter_(Dict): A data structure that describes the IP address filter to create, which consists of a name, an IP address range, and whether to allow or block mail from it.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.filter_.create(ctx, filter_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.filter.create filter_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="create_receipt_filter",
        op_kwargs={"Filter": filter_},
    )


async def delete(hub, ctx, filter_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified IP address filter. For information about managing IP address filters, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        filter_name(str): The name of the IP address filter to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.filter_.delete(ctx, filter_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.filter.delete filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_receipt_filter",
        op_kwargs={"FilterName": filter_name},
    )


async def list_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IP address filters associated with your AWS account in the current AWS Region. For information about managing IP address filters, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.filter_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.filter.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ses", operation="list_receipt_filters", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, resource_arn: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template. For more information, see SubscribeToEvent and UnsubscribeFromEvent.

    Args:
        resource_arn(str, optional): The ARN of the assessment template for which you want to list the existing event subscriptions. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListEventSubscriptions action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.event_subscription.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.event_subscription.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_event_subscriptions",
        op_kwargs={
            "resourceArn": resource_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, channel_arn: str, chime_bearer: str = None) -> Dict:
    r"""
    **Autogenerated function**

    The details of the time when a user last read messages in a channel.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.read_marker.update(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.read_marker.update channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_channel_read_marker",
        op_kwargs={"ChannelArn": channel_arn, "ChimeBearer": chime_bearer},
    )
